-- Title: Skill Helper
-- Author: JerichoHM
-- Version: 2.0
-- Desc: A simple addon for tracking and using skills

-- GLOBALS
local shVer = "2.0"
local SKILLCAP = 525
local shH1 = 14
local shH2 = 10
local shAlert = false

-- Main Title/Frame Definitions
local shMainTitle
local shMainTitleText
local shMainFrame

-- Profession Definitions
local shProf1, shProf1BG, shProf1Text, shProf1TitleText, shProf1BarBG, shProf1Bar, shProf1BarText
local shProf2, shProf2BG, shProf1Text, shProf2TitleText, shProf2BarBG, shProf2Bar, shProf2BarText
local shArch, shArchBG, shArchText, shArchTitleText, shArchBarBG, shArchBar, shArchBarText
local shFish, shFishBG, shFishText, shFishTitleText, shFishBarBG, shFishBar, shFishBarText
local shCook, shCookBG, shCookText, shCookTitleText, shCookBarBG, shCookBar, shCookBarText
local shFirstAid, shFirstAidBG, shFirstAidText, shFirstAidTitleText, shFirstAidBarBG, shFirstAidBar, shFirstAidBarText

function shLoadAddon()
	shMainFrameLoad()
end

function shMainFrameLoad()
	-- Title Frame
	shMainTitle = CreateFrame("Frame", "shMainTitle", UIParent)
	shMainTitle:SetFrameStrata("BACKGROUND")
	shMainTitle:SetSize(158, 25)
	shMainTitle:SetPoint("CENTER")
	
	-- Title Text
	shMainTitleText = shMainTitle:CreateFontString(nil, "BACKGROUND")
	isValid = shMainTitleText:SetFont("Fonts\\FRIZQT__.TTF", 14)
	shMainTitleText:SetTextColor(0.0, 0.7, 0.0, 1.0)
	shMainTitleText:SetText("Skill Helper " .. shVer)
	shMainTitleText:SetPoint("CENTER")
	
	-- Create Main Frame
	shMainFrame = CreateFrame("Frame", "shMainFrame", shMainTitle)
	shMainFrame:SetFrameStrata("BACKGROUND")
	shMainFrame:SetSize(158, 338)
	shMainFrame:SetPoint("BOTTOM", 0 , -338)
	
	-- Movability settings
	shMainTitle:SetClampedToScreen(true)
	shMainTitle:EnableMouse(true)
	shMainTitle:SetMovable(true)
	
	-- Drag and Drop controls
	shMainTitle:RegisterForDrag("LeftButton")
	shMainTitle:SetScript("OnDragStart", shMainTitle.StartMoving)
	shMainTitle:SetScript("OnDragStop", shMainTitle.StopMovingOrSizing)
	
	-- Show/Hide Controls
	shMainTitle:SetScript("OnEnter", shAutoHide)
	shMainTitle:SetScript("OnLeave", shAutoHide)
	shMainFrame:SetScript("OnLeave", shAutoHide)
	
	-- Event Handlers
	shMainTitle:RegisterEvent("SKILL_LINES_CHANGED")
	shMainTitle:SetScript("OnEvent", shOnEvent)
	
	-- Artwork
	local backdrop = { bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background.blp", edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border.blp", tile = true, tileSize = 32, edgeSize = 16, insets = {left = 3, right = 3, top = 3, bottom = 3}}
	shMainFrame:SetBackdrop(backdrop)
	shMainTitle:SetBackdrop(backdrop)
	
	-- Show Frame
	shMainTitle:Show()
	shMainFrame:Hide()
	
	shLoadFrames()
end

function shOnEvent(self, event)
	if event == "SKILL_LINES_CHANGED" then
		updateProfData()
	end
end

function shAutoHide()
	if not shMainFrame:IsVisible() then
		shMainFrame:Show()
	elseif shMainFrame:IsVisible() and not shMainFrame:IsMouseOver(0, 0, 0, 0) then
		shMainFrame:Hide()
	end
end

function shLoadFrames()
	shProf1Frame(nil, 0, 0, 0)
	
	shProf2Frame(nil, 0, 0, 0)
	
	shArchFrame(nil, 0, 0, 0)
	
	shFishFrame(nil, 0, 0, 0)
	
	shCookFrame(nil, 0, 0, 0)
	
	shFirstAidFrame(nil, 0, 0, 0)
end

function updateProfData()
	-- Capture the SkillIndes for the players Professions
	local prof1, prof2, archaeology, fishing, cooking, firstAid = GetProfessions()
	
	-- Build an array of the Professions
	local profs = {prof1, prof2, archaeology, fishing, cooking, firstAid}
	
	for k, v in pairs(profs) do 
		-- Fetch the details for each Profession 
		local name, texture, rank, maxRank, numSpells, spelloffset, skillLine, rankModifier = GetProfessionInfo(v)
		
		if k == 1 then
			shProf1Text:SetText(name)
			shProf1TitleText:SetText(shProfTitle(maxRank))
			shProf1Bar:SetValue(rank / maxRank)
			if	rank >= maxRank - 25 and maxRank < SKILLCAP then
				shAlert = true
				shProf1BarBG:SetStatusBarColor(0.7, 0.0, 0.0, 0.5)
				shProf1Bar:SetStatusBarColor(0.7, 0.0, 0.0, 1.0)
			else
				shProf1BarBG:SetStatusBarColor(0.0, 0.7, 0.0, 0.5)
				shProf1Bar:SetStatusBarColor(0.0, 0.7, 0.0, 1.0)
			end
			shProf1BarText:SetText(rank .. "+" .. rankModifier .. "/" .. maxRank)			
		elseif k == 2 then
			shProf2Text:SetText(name)
			shProf2TitleText:SetText(shProfTitle(maxRank))
			shProf2Bar:SetValue(rank / maxRank)
			if	rank >= maxRank - 25 and maxRank < SKILLCAP then
				shAlert = true
				shProf2BarBG:SetStatusBarColor(0.7, 0.0, 0.0, 0.5)
				shProf2Bar:SetStatusBarColor(0.7, 0.0, 0.0, 1.0)
			else
				shProf2BarBG:SetStatusBarColor(0.0, 0.7, 0.0, 0.5)
				shProf2Bar:SetStatusBarColor(0.0, 0.7, 0.0, 1.0)
			end
			shProf2BarText:SetText(rank .. "+" .. rankModifier .. "/" .. maxRank)
		elseif k == 3 then
			shArchText:SetText(name)
			shArchTitleText:SetText(shProfTitle(maxRank))
			shArchBar:SetValue(rank / maxRank)
			if	rank >= maxRank - 25 and maxRank < SKILLCAP then
				shAlert = true
				shArchBarBG:SetStatusBarColor(0.7, 0.0, 0.0, 0.5)
				shArchBar:SetStatusBarColor(0.7, 0.0, 0.0, 1.0)
			else
				shArchBarBG:SetStatusBarColor(0.0, 0.7, 0.0, 0.5)
				shArchBar:SetStatusBarColor(0.0, 0.7, 0.0, 1.0)
			end
			shArchBarText:SetText(rank .. "+" .. rankModifier .. "/" .. maxRank)
		elseif k == 4 then
			shFishText:SetText(name)
			shFishTitleText:SetText(shProfTitle(maxRank))
			shFishBar:SetValue(rank / maxRank)
			if	rank >= maxRank - 25 and maxRank < SKILLCAP then
				shAlert = true
				shFishBarBG:SetStatusBarColor(0.7, 0.0, 0.0, 0.5)
				shFishBar:SetStatusBarColor(0.7, 0.0, 0.0, 1.0)
			else
				shFishBarBG:SetStatusBarColor(0.0, 0.7, 0.0, 0.5)
				shFishBar:SetStatusBarColor(0.0, 0.7, 0.0, 1.0)
			end
			shFishBarText:SetText(rank .. "+" .. rankModifier .. "/" .. maxRank)
		elseif k == 5 then
			shCookText:SetText(name)
			shCookTitleText:SetText(shProfTitle(maxRank))
			shCookBar:SetValue(rank / maxRank)
			if	rank >= maxRank - 25 and maxRank < SKILLCAP then
				shAlert = true
				shCookBarBG:SetStatusBarColor(0.7, 0.0, 0.0, 0.5)
				shCookBar:SetStatusBarColor(0.7, 0.0, 0.0, 1.0)
			else
				shCookBarBG:SetStatusBarColor(0.0, 0.7, 0.0, 0.5)
				shCookBar:SetStatusBarColor(0.0, 0.7, 0.0, 1.0)
			end
			shCookBarText:SetText(rank .. "+" .. rankModifier .. "/" .. maxRank)
		elseif k == 6 then
			shFirstAidText:SetText(name)
			shFirstAidTitleText:SetText(shProfTitle(maxRank))
			shFirstAidBar:SetValue(rank / maxRank)
			if	rank >= maxRank - 25 and maxRank < SKILLCAP then
				shAlert = true
				shFirstAidBarBG:SetStatusBarColor(0.7, 0.0, 0.0, 0.5)
				shFirstAidBar:SetStatusBarColor(0.7, 0.0, 0.0, 1.0)
			else
				shFirstAidBarBG:SetStatusBarColor(0.0, 0.7, 0.0, 0.5)
				shFirstAidBar:SetStatusBarColor(0.0, 0.7, 0.0, 1.0)
			end
			shFirstAidBarText:SetText(rank .. "+" .. rankModifier .. "/" .. maxRank)
		end			
	end 
	
	if shAlert then
		shMainTitleText:SetTextColor(0.7, 0.0, 0.0, 1.0)
		shAlert = false
	else
		shMainTitleText:SetTextColor(0.0, 0.7, 0.0, 1.0)
	end
end

function shProf1Frame(name, rank, rankMod, rankMax)
	-- prof1 frame work start
	shProf1 = CreateFrame("Frame", "shProf1", shMainFrame)
	shProf1BG = { bgFile = nil, edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border.blp", tile = true, tileSize = 32, edgeSize = 16, insets = {left = 3, right = 3, top = 3, bottom = 3}}
	shProf1:SetBackdrop(shProf1BG)
	
	shProf1Text = shProf1:CreateFontString(nil, "BACKGROUND")
	isValid = shProf1Text:SetFont("Fonts\\FRIZQT__.TTF", shH1)
	shProf1Text:SetTextColor(1.0, 1.0, 0.0, 1.0)
	if name ~= nil then
		shProf1Text:SetText(name)
	else
		shProf1Text:SetText("Train Profession")
	end
	shProf1Text:SetPoint("TOPLEFT", 6, -6)
	
	shProf1TitleText = shProf1:CreateFontString(nil, "BACKGROUND")
	isValid = shProf1TitleText:SetFont("Fonts\\FRIZQT__.TTF", shH2)
	shProf1TitleText:SetText(shProfTitle(rankMax))
	shProf1TitleText:SetPoint("TOPLEFT", 6, -22)
	
	shProf1BarBG = CreateFrame("StatusBar", "shProf1BarBG", shProf1)
	shProf1BarBG:SetFrameStrata("BACKGROUND")
	shProf1BarBG:SetSize(140, 12)
	shProf1BarBG:SetMinMaxValues(0, 1)
	shProf1BarBG:SetValue(1)
	shProf1BarBG:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	shProf1BarBG:SetStatusBarColor(0.0, 0.7, 0.0, 0.5)
	shProf1BarBG:SetPoint("TOPLEFT", 5, -38)
	
	shProf1Bar = CreateFrame("StatusBar", "shProf1Bar", shProf1BarBG)
	shProf1Bar:SetFrameStrata("BACKGROUND")
	shProf1Bar:SetSize(140, 12)
	shProf1Bar:SetMinMaxValues(0, 1)
	if name ~= nil then
		shProf1Bar:SetValue(rank / rankMax)
	else
		shProf1Bar:SetValue(0)
	end
	shProf1Bar:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	shProf1Bar:SetStatusBarColor(0.0, 0.7, 0.0, 1.0)
	shProf1Bar:SetPoint("TOP")
	
	shProf1BarText = shProf1Bar:CreateFontString(nil, "ARTWORK")
	isValid = shProf1BarText:SetFont("Fonts\\FRIZQT__.TTF", 8)
	shProf1BarText:SetTextColor(1.0, 1.0, 1.0, 1.0)
	if name ~= nil then
		shProf1BarText:SetText(rank .. "+" .. rankMod .. "/" .. rankMax)
	else
		shProf1BarText:SetText("0+0/0")
	end
	shProf1BarText:SetPoint("CENTER")
	
	shProf1:SetFrameStrata("BACKGROUND")
	shProf1:SetSize(150, 55)
	shProf1:SetPoint("TOPLEFT", 4, -4)
	shProf1:Show()
	-- prof1 frame work end
end

function shProf2Frame(name, rank, rankMod, rankMax)
	-- prof2 frame work start
	shProf2 = CreateFrame("Frame", "shProf2", shMainFrame)
	shProf2BG = { bgFile = nil, edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border.blp", tile = true, tileSize = 32, edgeSize = 16, insets = {left = 3, right = 3, top = 3, bottom = 3}}
	shProf2:SetBackdrop(shProf2BG)
	
	shProf2Text = shProf2:CreateFontString(nil, "BACKGROUND")
	isValid = shProf2Text:SetFont("Fonts\\FRIZQT__.TTF", shH1)
	shProf2Text:SetTextColor(1.0, 1.0, 0.0, 1.0)
	if name ~= nil then
		shProf2Text:SetText(name)
	else
		shProf2Text:SetText("Train Profession")
	end
	shProf2Text:SetPoint("TOPLEFT", 6, -6)
	
	shProf2TitleText = shProf2:CreateFontString(nil, "BACKGROUND")
	isValid = shProf2TitleText:SetFont("Fonts\\FRIZQT__.TTF", shH2)
	shProf2TitleText:SetText(shProfTitle(rankMax))
	shProf2TitleText:SetPoint("TOPLEFT", 6, -22)
	
	shProf2BarBG = CreateFrame("StatusBar", "shProf2BarBG", shProf2)
	shProf2BarBG:SetFrameStrata("BACKGROUND")
	shProf2BarBG:SetSize(140, 12)
	shProf2BarBG:SetMinMaxValues(0, 1)
	shProf2BarBG:SetValue(1)
	shProf2BarBG:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	shProf2BarBG:SetStatusBarColor(0.0, 0.7, 0.0, 0.5)
	shProf2BarBG:SetPoint("TOPLEFT", 5, -38)
	
	shProf2Bar = CreateFrame("StatusBar", "shProf2Bar", shProf2BarBG)
	shProf2Bar:SetFrameStrata("BACKGROUND")
	shProf2Bar:SetSize(140, 12)
	shProf2Bar:SetMinMaxValues(0, 1)
	if name ~= nil then
		shProf2Bar:SetValue(rank / rankMax)
	else
		shProf2Bar:SetValue(0)
	end
	shProf2Bar:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	shProf2Bar:SetStatusBarColor(0.0, 0.7, 0.0, 1.0)
	shProf2Bar:SetPoint("TOP")
	
	shProf2BarText = shProf2Bar:CreateFontString(nil, "ARTWORK")
	isValid = shProf2BarText:SetFont("Fonts\\FRIZQT__.TTF", 8)
	shProf2BarText:SetTextColor(1.0, 1.0, 1.0, 1.0)
	if name ~= nil then
		shProf2BarText:SetText(rank .. "+" .. rankMod .. "/" .. rankMax)
	else
		shProf2BarText:SetText("0+0/0")
	end
	shProf2BarText:SetPoint("CENTER")
	
	shProf2:SetFrameStrata("BACKGROUND")
	shProf2:SetSize(150, 55)
	shProf2:SetPoint("TOPLEFT", 4, -59)
	shProf2:Show()
	-- prof2 frame work end
end

function shArchFrame(name, rank, rankMod, rankMax)
	-- archaeology frame work start
	shArch = CreateFrame("Frame", "shArch", shMainFrame)
	shArchBG = { bgFile = nil, edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border.blp", tile = true, tileSize = 32, edgeSize = 16, insets = {left = 3, right = 3, top = 3, bottom = 3}}
	shArch:SetBackdrop(shArchBG)
	
	shArchText = shArch:CreateFontString(nil, "BACKGROUND")
	isValid = shArchText:SetFont("Fonts\\FRIZQT__.TTF", shH1)
	shArchText:SetTextColor(1.0, 1.0, 0.0, 1.0)
	if name ~= nil then
		shArchText:SetText(name)
	else
		shArchText:SetText("Train Archaeology")
	end
	shArchText:SetPoint("TOPLEFT", 6, -6)
	
	shArchTitleText = shArch:CreateFontString(nil, "BACKGROUND")
	isValid = shArchTitleText:SetFont("Fonts\\FRIZQT__.TTF", shH2)
	shArchTitleText:SetText(shProfTitle(rankMax))
	shArchTitleText:SetPoint("TOPLEFT", 6, -22)
	
	shArchBarBG = CreateFrame("StatusBar", "shArchBarBG", shArch)
	shArchBarBG:SetFrameStrata("BACKGROUND")
	shArchBarBG:SetSize(140, 12)
	shArchBarBG:SetMinMaxValues(0, 1)
	shArchBarBG:SetValue(1)
	shArchBarBG:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	shArchBarBG:SetStatusBarColor(0.0, 0.7, 0.0, 0.5)
	shArchBarBG:SetPoint("TOPLEFT", 5, -38)
	
	shArchBar = CreateFrame("StatusBar", "shArchBar", shArchBarBG)
	shArchBar:SetFrameStrata("BACKGROUND")
	shArchBar:SetSize(140, 12)
	shArchBar:SetMinMaxValues(0, 1)
	if name ~= nil then
		shArchBar:SetValue(rank / rankMax)
	else
		shArchBar:SetValue(0)
	end
	shArchBar:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	shArchBar:SetStatusBarColor(0.0, 0.7, 0.0, 1.0)
	shArchBar:SetPoint("TOP")
	
	shArchBarText = shArchBar:CreateFontString(nil, "ARTWORK")
	isValid = shArchBarText:SetFont("Fonts\\FRIZQT__.TTF", 8)
	shArchBarText:SetTextColor(1.0, 1.0, 1.0, 1.0)
	if name ~= nil then
		shArchBarText:SetText(rank .. "+" .. rankMod .. "/" .. rankMax)
	else
		shArchBarText:SetText("0+0/0")
	end
	shArchBarText:SetPoint("CENTER")
	
	shArch:SetFrameStrata("BACKGROUND")
	shArch:SetSize(150, 55)
	shArch:SetPoint("TOPLEFT", 4, -114)
	shArch:Show()
	-- archaeology frame work end
end

function shFishFrame(name, rank, rankMod, rankMax)
	-- fishing frame work start
	shFish = CreateFrame("Frame", "shFish", shMainFrame)
	shFishBG = { bgFile = nil, edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border.blp", tile = true, tileSize = 32, edgeSize = 16, insets = {left = 3, right = 3, top = 3, bottom = 3}}
	shFish:SetBackdrop(shFishBG)
	
	shFishText = shFish:CreateFontString(nil, "BACKGROUND")
	isValid = shFishText:SetFont("Fonts\\FRIZQT__.TTF", shH1)
	shFishText:SetTextColor(1.0, 1.0, 0.0, 1.0)
	if name ~= nil then
		shFishText:SetText(name)
	else
		shFishText:SetText("Train Fishing")
	end
	shFishText:SetPoint("TOPLEFT", 6, -6)
	
	shFishTitleText = shFish:CreateFontString(nil, "BACKGROUND")
	isValid = shFishTitleText:SetFont("Fonts\\FRIZQT__.TTF", shH2)
	shFishTitleText:SetText(shProfTitle(rankMax))
	shFishTitleText:SetPoint("TOPLEFT", 6, -22)
	
	shFishBarBG = CreateFrame("StatusBar", "shFishBarBG", shFish)
	shFishBarBG:SetFrameStrata("BACKGROUND")
	shFishBarBG:SetSize(140, 12)
	shFishBarBG:SetMinMaxValues(0, 1)
	shFishBarBG:SetValue(1)
	shFishBarBG:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	shFishBarBG:SetStatusBarColor(0.0, 0.7, 0.0, 0.5)
	shFishBarBG:SetPoint("TOPLEFT", 5, -38)
	
	shFishBar = CreateFrame("StatusBar", "shFishBar", shFishBarBG)
	shFishBar:SetFrameStrata("BACKGROUND")
	shFishBar:SetSize(140, 12)
	shFishBar:SetMinMaxValues(0, 1)
	if name ~= nil then
		shFishBar:SetValue(rank / rankMax)
	else
		shFishBar:SetValue(0)
	end
	shFishBar:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	shFishBar:SetStatusBarColor(0.0, 0.7, 0.0, 1.0)
	shFishBar:SetPoint("TOP")
	
	shFishBarText = shFishBar:CreateFontString(nil, "ARTWORK")
	isValid = shFishBarText:SetFont("Fonts\\FRIZQT__.TTF", 8)
	shFishBarText:SetTextColor(1.0, 1.0, 1.0, 1.0)
	if name ~= nil then
		shFishBarText:SetText(rank .. "+" .. rankMod .. "/" .. rankMax)
	else
		shFishBarText:SetText("0+0/0")
	end
	shFishBarText:SetPoint("CENTER")
	
	shFish:SetFrameStrata("BACKGROUND")
	shFish:SetSize(150, 55)
	shFish:SetPoint("TOPLEFT", 4, -169)
	shFish:Show()
	-- fishing frame work end
end

function shCookFrame(name, rank, rankMod, rankMax)
	-- cooking frame work start
	shCook = CreateFrame("Frame", "shCook", shMainFrame)
	shCookBG = { bgFile = nil, edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border.blp", tile = true, tileSize = 32, edgeSize = 16, insets = {left = 3, right = 3, top = 3, bottom = 3}}
	shCook:SetBackdrop(shCookBG)
	
	shCookText = shCook:CreateFontString(nil, "BACKGROUND")
	isValid = shCookText:SetFont("Fonts\\FRIZQT__.TTF", shH1)
	shCookText:SetTextColor(1.0, 1.0, 0.0, 1.0)
	if name ~= nil then
		shCookText:SetText(name)
	else
		shCookText:SetText("Train Cooking")
	end
	shCookText:SetPoint("TOPLEFT", 6, -6)
	
	shCookTitleText = shCook:CreateFontString(nil, "BACKGROUND")
	isValid = shCookTitleText:SetFont("Fonts\\FRIZQT__.TTF", shH2)
	shCookTitleText:SetText(shProfTitle(rankMax))
	shCookTitleText:SetPoint("TOPLEFT", 6, -22)
	
	shCookBarBG = CreateFrame("StatusBar", "shCookBarBG", shCook)
	shCookBarBG:SetFrameStrata("BACKGROUND")
	shCookBarBG:SetSize(140, 12)
	shCookBarBG:SetMinMaxValues(0, 1)
	shCookBarBG:SetValue(1)
	shCookBarBG:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	shCookBarBG:SetStatusBarColor(0.0, 0.7, 0.0, 0.5)
	shCookBarBG:SetPoint("TOPLEFT", 5, -38)
	
	shCookBar = CreateFrame("StatusBar", "shCookBar", shCookBarBG)
	shCookBar:SetFrameStrata("BACKGROUND")
	shCookBar:SetSize(140, 12)
	shCookBar:SetMinMaxValues(0, 1)
	if name ~= nil then
		shCookBar:SetValue(rank / rankMax)
	else
		shCookBar:SetValue(0)
	end
	shCookBar:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	shCookBar:SetStatusBarColor(0.0, 0.7, 0.0, 1.0)
	shCookBar:SetPoint("TOP")
	
	shCookBarText = shCookBar:CreateFontString(nil, "ARTWORK")
	isValid = shCookBarText:SetFont("Fonts\\FRIZQT__.TTF", 8)
	shCookBarText:SetTextColor(1.0, 1.0, 1.0, 1.0)
	if name ~= nil then
		shCookBarText:SetText(rank .. "+" .. rankMod .. "/" .. rankMax)
	else
		shCookBarText:SetText("0+0/0")
	end
	shCookBarText:SetPoint("CENTER")
	
	shCook:SetFrameStrata("BACKGROUND")
	shCook:SetSize(150, 55)
	shCook:SetPoint("TOPLEFT", 4, -224)
	shCook:Show()
	-- cooking frame work end
end

function shFirstAidFrame(name, rank, rankMod, rankMax)
	-- firstAid frame work start
	shFirstAid = CreateFrame("Frame", "shFirstAid", shMainFrame)
	shFirstAidBG = { bgFile = nil, edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border.blp", tile = true, tileSize = 32, edgeSize = 16, insets = {left = 3, right = 3, top = 3, bottom = 3}}
	shFirstAid:SetBackdrop(shFirstAidBG)
	
	shFirstAidText = shFirstAid:CreateFontString(nil, "BACKGROUND")
	isValid = shFirstAidText:SetFont("Fonts\\FRIZQT__.TTF", shH1)
	shFirstAidText:SetTextColor(1.0, 1.0, 0.0, 1.0)
	if name ~= nil then
		shFirstAidText:SetText(name)
	else
		shFirstAidText:SetText("Train First Aid")
	end
	shFirstAidText:SetPoint("TOPLEFT", 6, -6)
	
	shFirstAidTitleText = shFirstAid:CreateFontString(nil, "BACKGROUND")
	isValid = shFirstAidTitleText:SetFont("Fonts\\FRIZQT__.TTF", shH2)
	shFirstAidTitleText:SetText(shProfTitle(rankMax))
	shFirstAidTitleText:SetPoint("TOPLEFT", 6, -22)
	
	shFirstAidBarBG = CreateFrame("StatusBar", "shFirstAidBarBG", shFirstAid)
	shFirstAidBarBG:SetFrameStrata("BACKGROUND")
	shFirstAidBarBG:SetSize(140, 12)
	shFirstAidBarBG:SetMinMaxValues(0, 1)
	shFirstAidBarBG:SetValue(1)
	shFirstAidBarBG:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	shFirstAidBarBG:SetStatusBarColor(0.0, 0.7, 0.0, 0.5)
	shFirstAidBarBG:SetPoint("TOPLEFT", 5, -38)
	
	shFirstAidBar = CreateFrame("StatusBar", "shFirstAidBar", shFirstAidBarBG)
	shFirstAidBar:SetFrameStrata("BACKGROUND")
	shFirstAidBar:SetSize(140, 12)
	shFirstAidBar:SetMinMaxValues(0, 1)
	if name ~= nil then
		shFirstAidBar:SetValue(rank / rankMax)
	else
		shFirstAidBar:SetValue(0)
	end
	shFirstAidBar:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	shFirstAidBar:SetStatusBarColor(0.0, 0.7, 0.0, 1.0)
	shFirstAidBar:SetPoint("TOP")
	
	shFirstAidBarText = shFirstAidBar:CreateFontString(nil, "ARTWORK")
	isValid = shFirstAidBarText:SetFont("Fonts\\FRIZQT__.TTF", 8)
	shFirstAidBarText:SetTextColor(1.0, 1.0, 1.0, 1.0)
	if name ~= nil then
		shFirstAidBarText:SetText(rank .. "+" .. rankMod .. "/" .. rankMax)
	else
		shFirstAidBarText:SetText("0+0/0")
	end
	shFirstAidBarText:SetPoint("CENTER")
	
	shFirstAid:SetFrameStrata("BACKGROUND")
	shFirstAid:SetSize(150, 55)
	shFirstAid:SetPoint("TOPLEFT", 4, -279)
	shFirstAid:Show()
	-- firstAid frame work end
end

function shProfTitle(rankMax)
	local title
	
	if rankMax == 75 or rankMax - 15 == 75 then
		title = "Apprentice"
	elseif rankMax == 150 or rankMax - 15 == 150 then
		title = "Journeyman"
	elseif rankMax == 225 or rankMax - 15 == 225 then
		title = "Expert"
	elseif rankMax == 300 or rankMax - 15 == 300 then
		title = "Artisan"
	elseif rankMax == 375 or rankMax - 15 == 375 then
		title = "Master"
	elseif rankMax == 450 or rankMax - 15 == 450 then
		title = "Grand Master"
	elseif rankMax == 525 or rankMax - 15 == 525 then
		title = "Illustrious"
	end
	
	return title
end

shLoadAddon()